local fn = vim.fn
local install_path = fn.stdpath('data')..'/site/pack/packer/start/packer.nvim'
if fn.empty(fn.glob(install_path)) > 0 then
  packer_bootstrap = fn.system({'git', 'clone', '--depth', '1', 'https://github.com/wbthomason/packer.nvim', install_path})
  vim.cmd [[packadd packer.nvim]]
end

return require('packer').startup(function(use)
  -- Packer can manage itself
  use 'wbthomason/packer.nvim'

  -- Nvim LSP
  use 'neovim/nvim-lspconfig'

  -- Tree-sitter
  use {
    'nvim-treesitter/nvim-treesitter',
    run = function() require('nvim-treesitter.install').update({ with_sync = true }) end,
  }

  -- Color schemes
  use 'morhetz/gruvbox'
  use 'sjl/badwolf'

  -- Auto close parens and such
  use 'Townk/vim-autoclose'

  -- Surround
  use 'tpope/vim-surround'

  -- NERDTree
  use 'preservim/nerdtree'
  use 'Xuyuanp/nerdtree-git-plugin' -- A NERDTree plugin showing git status

  -- VimTeX
  use 'lervag/vimtex'

  -- Automatically set up your configuration after cloning packer.nvim
  -- Put this at the end after all plugins
  if packer_bootstrap then
    require('packer').sync()
  end
end)
